@@ -68,15 +68,6 @@
   (let* ((config (dumb-jump-read-config test-data-dir-proj1 ".dumbjump-lang")))
     (should (string= "python" (plist-get config :language)))))
 
-(ert-deftest dumb-jump-read-config-remote-test ()
-  (with-mock
-    (mock (f-read-text *) => "-exclude_path1\n+include_path1\n-exclude_path2\n+../include_path2\n+/usr/lib/include_path3")
-    (let ((result (dumb-jump-read-config "/ssh:1.2.3.4:/usr/blah" "dummy-config"))
-          (exclude-paths '("/usr/blah/exclude_path1" "/usr/blah/exclude_path2"))
-          (include-paths '("/usr/blah/include_path1" "/usr/include_path2" "/usr/lib/include_path3")))
-      (should (equal (plist-get result :exclude) exclude-paths))
-      (should (equal (plist-get result :include) include-paths)))))
-
 (ert-deftest dumb-jump-language-to-ext-test ()
   (should (-contains? (dumb-jump-get-file-exts-by-language "elisp") "el")))
 
@@ -433,14 +424,14 @@
 (ert-deftest dumb-jump-context-point-test ()
   (let* ((sentence "mainWindow.loadUrl('file://')")
          (func "loadUrl")
-         (ctx (dumb-jump-get-point-context sentence func 15)))
+         (ctx (dumb-jump-get-point-context sentence func 11)))
          (should (string= (plist-get ctx :left) "mainWindow."))
          (should (string= (plist-get ctx :right) "('file://')"))))
 
 (ert-deftest dumb-jump-context-point-type-test ()
   (let* ((sentence "mainWindow.loadUrl('file://' + __dirname + '/dt/inspector.html?electron=true');")
          (func "loadUrl")
-         (pt-ctx (dumb-jump-get-point-context sentence func 14))
+         (pt-ctx (dumb-jump-get-point-context sentence func 11))
          (ctx-type (dumb-jump-get-ctx-type-by-language "javascript" pt-ctx)))
     (should (string= ctx-type "function"))))
 
@@ -457,7 +448,7 @@
          (results '((:path "/usr/blah/test.txt" :line 54 :context "function thing()")
                     (:path "/usr/blah/test2.txt" :line 52 :context "var thing = function()" :target "a"))))
     (with-mock
-     (mock (helm-build-sync-source * :action * :candidates * :persistent-action *))
+     (mock (helm-make-source "Jump to: " 'helm-source-sync :action * :candidates * :persistent-action *))
      (mock (helm * * :buffer "*helm dumb jump choices*"))
      (dumb-jump-prompt-user-for-choice "/usr/blah" results))))
 
@@ -467,11 +458,12 @@
 
 (ert-deftest dumb-jump-prompt-user-for-choice-correct-ivy-test ()
   (let* ((dumb-jump-selector 'ivy)
+         (dumb-jump-ivy-jump-to-selected-function
+          #'dumb-jump-ivy-jump-to-selected)
          (results '((:path "/usr/blah/test.txt" :line 54 :context "function thing()")
                     (:path "/usr/blah/test2.txt" :line 52 :context "var thing = function()" :target "a"))))
     (with-mock
-     (mock (ivy-read * *)  => "/test2.txt:52: var thing = function()")
-     (mock (dumb-jump-result-follow '(:path "/usr/blah/test2.txt" :line 52 :context "var thing = function()" :target "a")))
+     (mock (ivy-read * * :action * :caller *)  => "/test2.txt:52: var thing = function()")
      (dumb-jump-prompt-user-for-choice "/usr/blah" results))))
 
 (ert-deftest dumb-jump-a-back-test ()
@@ -714,9 +706,10 @@
       (goto-char (point-min))
       (noflet ((dumb-jump-fetch-file-results (&optional prompt)
                  (sleep-for 0 300)
-                 '()))
+                 '(:results (:result))))
         (with-mock
           (mock (dumb-jump-message "Took over %ss to find '%s'. Please install ag or rg, or add a .dumbjump file to '%s' with path exclusions" * * *))
+          (mock (dumb-jump-result-follow * * *))
           (dumb-jump-go))))))
 
 (ert-deftest dumb-jump-message-handle-results-test ()
@@ -924,12 +917,6 @@
      (mock (dumb-jump-goto-file-line "/usr/blah/test2.txt" 52 1))
      (dumb-jump--result-follow data nil "/usr/blah"))))
 
-(ert-deftest dumb-jump-find-start-pos-test ()
-  (let ((cur-pos 9)
-        (line "event event")
-        (word "event"))
-    (should (= (dumb-jump-find-start-pos line word cur-pos) 6))))
-
 (ert-deftest dumb-jump-go-include-lib-test ()
   (let ((el-file (f-join test-data-dir-elisp "fake2.el"))
         (lib-file (f-join test-data-dir-elisp "../fake-library/lib.el")))
@@ -1264,7 +1251,7 @@
      (mock (popup-menu* '("relfile.js:62: var isNow = true" "src/absfile.js:69: isNow = false")) :times 1)
      (dumb-jump-handle-results results "relfile.js" "/code/redux" "" "isNow" t nil))))
 
-;; Make sure it jumps when there's only one possiblity in non-aggressive mode.
+;; Make sure it jumps when there's only one possibility in non-aggressive mode.
 (ert-deftest dumb-jump-handle-results-non-aggressive-do-jump-test ()
   (let ((dumb-jump-aggressive nil)
         (results '((:path "relfile.js" :line 62 :context "var isNow = true" :diff 7 :target "isNow"))))
